@@ -10,7 +10,7 @@
 mod_start_simulation_ui <- function(id) {
   ns <- NS(id)
   tagList(
-    actionButton(ns("run_button"), "Run Tests") %>%
+    actionButton(ns("run_button"), "Run Simulations") %>%
       tagAppendAttributes(class = "btn btn-success")
   )
 }
